@@ -117,7 +117,7 @@ def _read_block_items(docstring: Docstring, offset: int) -> ItemsBlock:  # noqa:
 def _read_block(docstring: Docstring, offset: int) -> tuple[str, int]:
     lines = docstring.lines
     if offset >= len(lines):
-        return "", offset
+        return "", offset - 1
 
     new_offset = offset
     block: list[str] = []
@@ -131,7 +131,7 @@ def _read_block(docstring: Docstring, offset: int) -> tuple[str, int]:
 
     if indent == 0:
         # first non-empty line was not indented, abort
-        return "", new_offset - 1
+        return "", offset - 1
 
     # start processing first item
     block.append(lines[new_offset].lstrip())
@@ -215,7 +215,7 @@ def _read_attributes_section(docstring: Docstring, offset: int) -> tuple[Docstri
     attributes = []
     block, new_offset = _read_block_items(docstring, offset)
 
-    annotation: str | Name | Expression | None
+    annotation: str | Name | Expression | None = None
     for line_number, attr_lines in block:
         try:
             name_with_type, description = attr_lines[0].split(":", 1)
@@ -234,10 +234,8 @@ def _read_attributes_section(docstring: Docstring, offset: int) -> tuple[Docstri
             annotation = parse_annotation(annotation, docstring)
         else:
             name = name_with_type
-            try:
-                annotation = docstring.parent.attributes[name].annotation  # type: ignore[union-attr]
-            except (AttributeError, KeyError):
-                annotation = None
+            with suppress(AttributeError, KeyError):
+                annotation = docstring.parent.members[name].annotation  # type: ignore[union-attr]
 
         attributes.append(DocstringAttribute(name=name, annotation=annotation, description=description))
 
@@ -499,6 +497,7 @@ _section_reader = {
 
 def parse(  # noqa: WPS231
     docstring: Docstring,
+    ignore_init_summary: bool = False,
     **options: Any,
 ) -> list[DocstringSection]:
     """Parse a docstring.
@@ -508,6 +507,7 @@ def parse(  # noqa: WPS231
 
     Parameters:
         docstring: The docstring to parse.
+        ignore_init_summary: Whether to ignore the summary in `__init__` methods' docstrings.
         **options: Additional parsing options.
 
     Returns:
@@ -517,9 +517,21 @@ def parse(  # noqa: WPS231
     current_section = []
 
     in_code_block = False
-
     lines = docstring.lines
-    offset = 0
+
+    ignore_summary = (
+        ignore_init_summary  # noqa: WPS222
+        and docstring.parent is not None
+        and docstring.parent.name == "__init__"
+        and docstring.parent.is_function
+        and docstring.parent.parent is not None
+        and docstring.parent.parent.is_class
+    )
+
+    if ignore_summary:
+        offset = 2
+    else:
+        offset = 0
 
     while offset < len(lines):
         line_lower = lines[offset].lower()
@@ -570,7 +582,6 @@ def parse(  # noqa: WPS231
                             )
                         )
                     else:
-                        offset -= 1
                         with suppress(IndexError):
                             current_section.append(lines[offset])
             else:
