@@ -7,7 +7,7 @@ from griffe import cli
 
 def test_main():
     """Basic CLI test."""
-    assert cli.main(["griffe", "-s", "src"]) == 0
+    assert cli.main(["griffe", "-s", "src", "-o/dev/null"]) == 0
 
 
 def test_show_help(capsys):
